@@ -8,6 +8,7 @@ import uuid
 import lxml.etree
 
 from .database import Database
+from .settings import PelicanMathSettings
 
 DEFAULT_PREAMBLE = [
     r"\documentclass[crop,border={2pt 0pt}]{standalone}",
@@ -32,7 +33,31 @@ def remove_svg_pageid(code: str) -> str:
     return lxml.etree.tostring(doc).decode()
 
 
-def render_svg(math: str) -> str:
+def run_scour(code: str, args: list[str]) -> str:
+    return (
+        subprocess.check_output(
+            [
+                "scour",
+            ]
+            + args,
+            input=code.encode(),
+        )
+        .decode()
+        .strip()
+    )
+
+
+def run_svgo(code: str, args: list[str]) -> str:
+    return (
+        subprocess.check_output(
+            ["svgo", "--input", "-", "--output", "-"] + args, input=code.encode()
+        )
+        .decode()
+        .strip()
+    )
+
+
+def render_svg(math: str, settings: PelicanMathSettings) -> str:
     path_shelf = Path(".cache") / "pelican-math-svg"
     path_shelf.parent.mkdir(exist_ok=True, parents=True)
 
@@ -44,12 +69,12 @@ def render_svg(math: str) -> str:
     equation = math.strip()
 
     db = Database()
-    svg = db.fetch_rendered_equation(equation)
-    if svg is not None:
+    svg, settings_string = db.fetch_rendered_equation(equation)
+    if (svg is not None) and (settings_string == settings.serialize()):
         return svg
 
     if dry_mode:
-        db.add_equation(equation)
+        db.add_equation(equation, settings)
         return f"<code>${equation}$</code>"
 
     equationid = uuid.uuid4().hex
@@ -108,9 +133,15 @@ def render_svg(math: str) -> str:
         svg = remove_svg_comments(svg)
         svg = remove_svg_pageid(svg)
 
+        if settings.scour:
+            svg = run_scour(svg, settings.scour_args)
+
+        if settings.svgo:
+            svg = run_svgo(svg, settings.svgo_args)
+
         shutil.rmtree(working_dir)
 
-        db.add_equation(equation, svg)
+        db.add_equation(equation, settings, svg)
         return svg
 
     except subprocess.CalledProcessError:
